( cd opt/kde/lib ; rm -rf libk3bcore.so )
( cd opt/kde/lib ; ln -sf libk3bcore.so.2.0.0 libk3bcore.so )
( cd opt/kde/lib ; rm -rf libk3bcore.so.2 )
( cd opt/kde/lib ; ln -sf libk3bcore.so.2.0.0 libk3bcore.so.2 )
( cd opt/kde/lib ; rm -rf libk3bdevice.so )
( cd opt/kde/lib ; ln -sf libk3bdevice.so.2.0.0 libk3bdevice.so )
( cd opt/kde/lib ; rm -rf libk3bdevice.so.2 )
( cd opt/kde/lib ; ln -sf libk3bdevice.so.2.0.0 libk3bdevice.so.2 )
( cd opt/kde/lib ; rm -rf libk3bplugin.so )
( cd opt/kde/lib ; ln -sf libk3bplugin.so.2.0.0 libk3bplugin.so )
( cd opt/kde/lib ; rm -rf libk3bplugin.so.2 )
( cd opt/kde/lib ; ln -sf libk3bplugin.so.2.0.0 libk3bplugin.so.2 )
( cd opt/kde/lib ; rm -rf libk3bproject.so )
( cd opt/kde/lib ; ln -sf libk3bproject.so.2.0.0 libk3bproject.so )
( cd opt/kde/lib ; rm -rf libk3bproject.so.2 )
( cd opt/kde/lib ; ln -sf libk3bproject.so.2.0.0 libk3bproject.so.2 )
( cd opt/kde/lib ; rm -rf libk3btools.so )
( cd opt/kde/lib ; ln -sf libk3btools.so.2.0.0 libk3btools.so )
( cd opt/kde/lib ; rm -rf libk3btools.so.2 )
( cd opt/kde/lib ; ln -sf libk3btools.so.2.0.0 libk3btools.so.2 )
( cd opt/kde/share/doc/HTML/en/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/k3b ; ln -sf /opt/kde/share/doc/HTML/en/common common )
