<!DOCTYPE kpartgui>
<kpartplugin name="k3baudiometainforenamerplugin" library="libk3baudiometainforenamerplugin">
<MenuBar>
 <Menu name="plugins"><text>Plugins</text>
  <Action name="rename_audio_files_plugin"/>
 </Menu>
</MenuBar>
</kpartplugin>
